==> aws-cdk-microservice-0.0.11.tar.gz: package/lib/constructs/microservice.d.ts <==
import { CfnAutoScalingGroup } from '@aws-cdk/aws-autoscaling';
import { Construct } from '@aws-cdk/core';
import { IngressRule, InternalRole } from './autoScalingGroup';
/**
 * @stability stable
 */
export interface MicroServiceProps {
    /**
     * @stability stable
     */
    readonly env: string;
    /**
     * @stability stable
     */
    readonly instanceType?: string;
    /**
     * @stability stable
     */
    readonly appName: string;
    /**
     * @stability stable
     */
    readonly asgMaxSize?: string;
    /**
     * @stability stable
     */
    readonly asgMinSize?: string;
    /**
     * @stability stable
     */
    readonly instanceLabels?: CfnAutoScalingGroup.TagPropertyProperty[];
    /**
     * @stability stable
     */
    readonly healthCheckPath?: string;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly vpc: string;
    /**
     * @stability stable
     */
    readonly subnets: string[];
    /**
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * @stability stable
     */
    readonly diskSize?: number;
    /**
     * @stability stable
     */
    readonly role: InternalRole;
    /**
     * @stability stable
     */
    readonly tcpRules?: IngressRule[];
    /**
     * @stability stable
     */
    readonly sslEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly host?: string;
    /**
     * @stability stable
     */
    readonly lbArn?: string;
    /**
     * @stability stable
     */
    readonly ami?: string;
    /**
     * @stability stable
     */
    readonly sshKey: string;
    /**
     * @stability stable
     */
    readonly diskType?: string;
    /**
     * @stability stable
     */
    readonly createCodedeployApplication?: boolean;
    /**
     * @stability stable
     */
    readonly deploymentPolicies?: string[];
    /**
     * @stability stable
     */
    readonly applicationType?: string;
}
/**
 * @stability stable
 */
export declare class MicroService extends Construct {
    /**
     * @stability stable
     */
    readonly instanceType?: string;
    /**
     * @stability stable
     */
    readonly appName: string;
    /**
     * @stability stable
     */
    readonly asgMaxSize?: string;
    /**
     * @stability stable
     */
    readonly asgMinSize?: string;
    /**
     * @stability stable
     */
    readonly env?: string;
    /**
     * @stability stable
     */
    readonly instanceLabels?: CfnAutoScalingGroup.TagPropertyProperty[];
    /**
     * @stability stable
     */
    readonly healthCheckPath?: string;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * @stability stable
     */
    readonly diskSize?: number;
    /**
     * @stability stable
     */
    readonly vpc: string;
    /**
     * @stability stable
     */
    readonly role: InternalRole;
    /**
     * @stability stable
     */
    readonly tcpRules?: IngressRule[];
    /**
     * @stability stable
     */
    readonly subnets: string[];
    /**
     * @stability stable
     */
    readonly sslEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly host?: string;
    /**
     * @stability stable
     */
    readonly lbArn?: string;
    /**
     * @stability stable
     */
    readonly sshKey: string;
    /**
     * @stability stable
     */
    readonly diskType?: string;
    /**
     * @stability stable
     */
    readonly createCodedeployApplication?: boolean;
    /**
     * @stability stable
     */
    readonly deploymentPolicies?: string[];
    /**
     * @stability stable
     */
    readonly applicationType?: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: MicroServiceProps);
    private getDeploymentGroupRole;
    private getDiskType;
}

==> aws-cdk-microservice-0.0.15.tar.gz: package/lib/constructs/microservice.d.ts <==
import { CfnAutoScalingGroup } from 'aws-cdk-lib/aws-autoscaling';
import { Construct } from 'constructs';
import { IngressRule, NetworkProps, InternalSG, TargetGroupProps, InternalRole } from './autoScalingGroup';
export interface MicroServiceProps {
    readonly env: string;
    readonly instanceType?: string;
    readonly appName: string;
    readonly asgMaxSize?: string;
    readonly asgMinSize?: string;
    readonly instanceLabels?: CfnAutoScalingGroup.TagPropertyProperty[];
    readonly vpc: string;
    readonly subnets: string[];
    readonly diskSize?: number;
    readonly role: InternalRole;
    readonly tcpRules?: IngressRule[];
    readonly ami?: string;
    readonly sshKey: string;
    readonly diskType?: string;
    readonly createCodedeployApplication?: boolean;
    readonly deploymentPolicies?: string[];
    readonly applicationType?: string;
    readonly securityGroupProps?: InternalSG;
    readonly networkProps?: NetworkProps[];
}
export declare class MicroService extends Construct {
    readonly instanceType?: string;
    readonly appName: string;
    readonly asgMaxSize?: string;
    readonly asgMinSize?: string;
    readonly env?: string;
    readonly instanceLabels?: CfnAutoScalingGroup.TagPropertyProperty[];
    readonly diskSize?: number;
    readonly vpc: string;
    readonly role: InternalRole;
    readonly tcpRules?: IngressRule[];
    readonly subnets: string[];
    readonly sshKey: string;
    readonly diskType?: string;
    readonly createCodedeployApplication?: boolean;
    readonly deploymentPolicies?: string[];
    readonly applicationType?: string;
    readonly securityGroupProps?: InternalSG;
    readonly networkProps?: NetworkProps[];
    readonly targetGroupProps: TargetGroupProps[];
    constructor(scope: Construct, id: string, props: MicroServiceProps);
    private getDeploymentGroupRole;
    private getDiskType;
}
